This is a lib of making images ascii and colored, have fun

generate_image is a generator to print many images at once

print_image just prints, columns and rows is relation to term size

show_gif shows a slide show
